# oaxaca

[![Release](https://img.shields.io/github/v/release/anhqle/oaxaca)](https://img.shields.io/github/v/release/anhqle/oaxaca)
[![Build status](https://img.shields.io/github/actions/workflow/status/anhqle/oaxaca/main.yml?branch=main)](https://github.com/anhqle/oaxaca/actions/workflows/main.yml?query=branch%3Amain)
[![codecov](https://codecov.io/gh/anhqle/oaxaca/branch/main/graph/badge.svg)](https://codecov.io/gh/anhqle/oaxaca)
[![Commit activity](https://img.shields.io/github/commit-activity/m/anhqle/oaxaca)](https://img.shields.io/github/commit-activity/m/anhqle/oaxaca)
[![License](https://img.shields.io/github/license/anhqle/oaxaca)](https://img.shields.io/github/license/anhqle/oaxaca)

Oaxaca Blinder decomposition

- **Github repository**: <https://github.com/anhqle/oaxaca/>
- **Documentation** <https://anhqle.github.io/oaxaca/>
- **Demo** <https://github.com/anhqle/oaxaca/blob/main/notebooks/minimal_oaxaca_demo.ipynb>
